#ifndef JCC71DetectorConstruction_h
#define JCC71DetectorConstruction_h 1

#include "JCC71Material.hh"
#include "JCC71SDTracker.hh"

#include "G4TransportationManager.hh"
#include "G4LogicalVolume.hh"
#include "G4PVPlacement.hh"
#include "G4Box.hh"
#include "G4Cons.hh"
#include "G4Orb.hh"
#include "G4Tubs.hh"
#include "G4Sphere.hh"
#include "G4Trd.hh"
#include "G4RotationMatrix.hh"

#include "G4VUserDetectorConstruction.hh"

#include "G4SDManager.hh"
#include "JCC71SDTracker.hh"


#include <vector>
#include "globals.hh"
//#include "G4Cache.hh"
//#include "G4AutoDelete.hh"



class G4VPhysicalVolume;
class G4LogicalVolume;



class JCC71DetectorConstruction : public G4VUserDetectorConstruction
{

	public:
	JCC71DetectorConstruction();
	virtual ~JCC71DetectorConstruction();

	public:
	virtual G4VPhysicalVolume* Construct();
	virtual void ConstructSDandField();


	public:
	void BuildSlabAssembly();
	void BuildPolyBlock();
	void BuildHeTubes();
	void BuildPolyChamfer();
	void BuildAlBackPlate();
	void BuildAlElectSupport();
	void BuildElectBox();


	private:
	G4Box* World;				// World Declaration
	G4LogicalVolume* LogWorld;
	G4VPhysicalVolume* PhyWorld;


	G4Box* SlabAssembly;			// Assembly Declaration
	G4LogicalVolume* LogSlabAssembly;
	G4VPhysicalVolume* PhySlabAssembly;	


	G4Box* AlBackPlate;			// Al Back Plate Declaration
	G4LogicalVolume* LogAlBackPlate;
	G4VPhysicalVolume* PhyAlBackPlate;		

	
	G4Trd* PolyChamfer;			// Top Poly Chamfer
	G4LogicalVolume* LogPolyChamfer;
	G4VPhysicalVolume* PhyPolyChamfer;

	
	G4Box* PolyBlock;			// Bottom Poly Block
	G4LogicalVolume* LogPolyBlock;
	G4VPhysicalVolume* PhyPolyBlock;

	
	G4Tubs* HeTube[6];			// Helium Tubes
	G4LogicalVolume* LogHeTube[6];
	G4VPhysicalVolume* PhyHeTube[6];

	
	G4Box* AlElectSupportTop;		// Alumium Connector Poly and Electronics
	G4LogicalVolume* LogAlElectSupportTop;
	G4VPhysicalVolume* PhyAlElectSupportTop;


	G4Box* AlElectSupportBottom;		// Alumium Connector Poly and Electronics
	G4LogicalVolume* LogAlElectSupportBottom;
	G4VPhysicalVolume* PhyAlElectSupportBottom;


	G4Box* ElectBox;			// Electronics (Not Active)
	G4LogicalVolume* LogElectBox;
	G4VPhysicalVolume* PhyElectBox;




private:

//	G4Cache<JCC71SDTracker*> trackerSD;

	G4String sensitiveDetectorName;
	G4VisAttributes* GeoVis;

	JCC71SDTracker*	pJCC71TSD;
	JCC71Material* pMat;


	G4RotationMatrix* pRot;
	
	G4double WorldSizeX;
	G4double WorldSizeY;
	G4double WorldSizeZ;

	G4double AssSizeX;
	G4double AssSizeY;
	G4double AssSizeZ;


	G4double PolySizeX;
	G4double PolySizeY;
	G4double PolySizeZ;

	G4double BackPlateSizeX;
	G4double BackPlateSizeY;
	G4double BackPlateSizeZ;

	G4double HeTubeR1;
	G4double HeTubeR2;
	G4double HeTubeH;

	G4double ChamSizeX1;
	G4double ChamSizeX2;
	G4double ChamSizeY1;
	G4double ChamSizeY2;
	G4double ChamSizeZ;

	G4bool checkOverlaps = false;

};

#endif
