#ifndef JCC7FissionEvent_h
#define JCC7FissionEvent_h 1


#include "globals.hh"
#include <string>

class JCC71FissionEvent 
{

   private:
      G4int neutronNu; // number of neutrons in this fission event
      G4double* neutronEnergies; 
      G4double* neutronVelocities; 
      G4double* neutronDircosu; 
      G4double* neutronDircosv; 
      G4double* neutronDircosw; 
      G4double* neutronAges; 


      // options
      static G4int delayoption;
      static G4int correlationoption;
      static G4int nudistoption;
      static G4int Cf252ndistoption;
      static G4int Cf252nengoption;
      static G4double (*rngdptr)(void);
      static float (*rngfptr)(void);

   public:
      // These are all the methods of this class accessible to the caller of the object 
      JCC71FissionEvent(G4int isotope, G4double time, G4double nubar, G4double eng);
      ~JCC71FissionEvent();

      G4int getNeutronNu() {
         return neutronNu;
      }

      G4double getNeutronEnergy(G4int index) {
         if (index >= 0 && index < neutronNu) return neutronEnergies[index];
         else return -1;
      }

      G4double getNeutronVelocity(G4int index) {
         if (index >= 0 && index < neutronNu) return neutronVelocities[index];
         else return -1;
      }

      G4double getNeutronDircosu(G4int index) {
         if (index >= 0 && index < neutronNu) return neutronDircosu[index];
         else return -1;
      }

      G4double getNeutronDircosv(G4int index) {
         if (index >= 0 && index < neutronNu) return neutronDircosv[index];
         else return -1;
      }

      G4double getNeutronDircosw(G4int index) {
         if (index >= 0 && index < neutronNu) return neutronDircosw[index];
         else return -1;
      }

      G4double getNeutronAge(G4int index) {
         if (index >= 0 && index < neutronNu) return neutronAges[index];
         else return -1;
      }

      static void setDelayOption(G4int delay) {
         delayoption = delay;
      };
      static void setCorrelationOption(G4int correlation) {
         correlationoption = correlation;
      };
      static void setNudistOption(G4int nudist) {
         nudistoption = nudist;
      };
      static void setCf252Option(G4int ndist, G4int neng) {
         Cf252ndistoption = ndist;
         Cf252nengoption = neng;
      };
      static void setRNGf(float (*funcptr) (void)) {
         rngfptr = funcptr;
         rngdptr = rngf2d;
      }
      static void setRNGd(G4double (*funcptr) (void)) {
         rngdptr = funcptr;
      }


   private:

      G4double JCC71SmpNEngCf252(G4int option);
      G4double JCC71SmpNVel(G4double eng, G4double* cosdiru, G4double* cosdirv, G4double* cosdirw);
      void JCC71SmpIsoDir(G4double* cosdiru, G4double* cosdirv, G4double* cosdirw);
      G4int JCC71SmpSpNuDistData(G4int isotope, G4int Cf252option);
      G4double JCC71SmpSpNubarData(G4int isotope);
      G4double JCC71SmpTerrell(G4double nubar);
      G4double JCC71SmpWatt(G4double ePart, G4int iso);
      void JCC71Fissionerr(G4int iSever, std::string chSubNam, std::string chMsg);
      static G4double fisslibrng(void);
      static G4double rngf2d(void);
};


#endif
