#include "JCC71FissionEvent.hh"

#include <cmath>


G4double JCC71FissionEvent::JCC71SmpNVel(G4double eng, G4double* cosdiru, G4double* cosdirv, G4double* cosdirw) {

/*
  Description
    Knowing the neutron energy, determine its velocity and the 3 direction cosines
*/

/*
  Input
    eng     - energy of neutron
  Output
            - velocity
            - 3 components of the neutron velocity
              in arguments (cosdiru, cosdirv, cosdirw)
*/

   const G4double rme = 939.56563; /* Rest Mass Energy equivalents for neutrons (MeV) */
   const G4double cspeed = 2.99792458e+8; /* speed of light (m/sec) */

   G4double vel;
   G4double ratio = eng/rme;

   if (ratio > 1.e-8) {
/*    Relativistic vel calculation */
      vel = cspeed*std::sqrt(1.-rme*rme/((rme+eng)*(rme+eng)));
   } else {
/*    Non-relativistic vel calculation */
      vel = cspeed*std::sqrt(2.*eng/rme);
   }

   JCC71SmpIsoDir(cosdiru, cosdirv, cosdirw);

   return vel;
}

